import Icon, {
  MenuFoldOutlined, MenuUnfoldOutlined,
  DatabaseOutlined, DatabaseFilled
} from '@ant-design/icons';
import { Row, Col, Divider } from 'antd';
import { Button, Layout, Menu, Tabs } from 'antd';
import 'antd/dist/antd.css';
import React from 'react';
import './App.less';
import DataTable from './Table';
import ContentTable from './ContentTable';
import DataTableTest from './TableTest';
import ChartsCount from './ChartsCount';

const { TabPane }  = Tabs;
const bstyle = {  width: "100px" };
const { Header, Content, Footer, Sider } = Layout;

class App extends React.Component {
  state = {
    platform: "openrec",
    collapsed: false,
    tkey: "content_table",
  };

  toggleCollapsed = () => {
    this.setState({
      collapsed: !this.state.collapsed,
    });
  };

  changePlatform = (p) => {
    this.setState({platform: p});
    if (this.refs.tcharts && this.refs.tcharts.state.platform !== p) {
      this.refs.tcharts.changePlatform(p)
    }
    this.refs.ctable.changePlatform(p);
  }

  render() {
    return (
      <Layout>
        <Sider
            trigger={null}
            collapsible
            collapsed={this.state.collapsed}
            inlineCollapsed={this.state.collapsed} 
        >
        <Button type="primary" onClick={this.toggleCollapsed} style={{ background: '#6739b6', width: "100%", colorRendering: "optimizeSpeed" }}>
            {React.createElement(this.state.collapsed ? MenuUnfoldOutlined : MenuFoldOutlined)}
        </Button>
          <Menu theme="dark" mode="inline" defaultSelectedKeys={['1']}
          defaultOpenKeys={['sub1']}
          >
              <Menu.Item key="openrec" icon={<DatabaseFilled/>} onClick={(e)=>{    this.changePlatform(e.key);  }}  >
                  openrec
              </Menu.Item>
              <Menu.Item key="twitcasting" icon={<DatabaseFilled/>} onClick={(e)=>{    this.changePlatform(e.key); ;  }}  >
                  twitcasting
              </Menu.Item>
              <Menu.Item key="twitch" icon={<DatabaseFilled/>} onClick={(e)=>{    this.changePlatform(e.key); }}  >
                twitch
              </Menu.Item>
          </Menu>
      </Sider>
  <Layout>
  <Header style={{ background: '#000', padding:"0" }}>
  
        <Divider orientation="left" style={{height: "100%"}}  >
          <Row justify="center" gutter={{lg: 128 }}>
            {/* <Col  span={4}><Button type="primary" style={bstyle} onClick={(e)=>{}}> tag统计 </Button> </Col> */}
          </Row>
        </Divider>
    
  </Header>
  <Content ref="content"  style={{ margin: '0 8px' }}>
      <Tabs  
       onChange={(e)=>{ 
            const { platform } = this.state;
            this.setState({key: e})

            switch (e) {
              case "content_table":
                if (this.refs.ctable) {
                  this.refs.ctable.changePlatform(platform);
                }
                break;
              case "tag_count":
                if( this.refs.tcharts ) {
                  this.refs.tcharts.changePlatform(platform);
                }
                break
              default:
                break;
            }
            
       }} >

        <TabPane  tab="数据表格" key="content_table">
          <ContentTable  ref="ctable" platform={this.state.platform}></ContentTable>
        </TabPane>
        <TabPane  tab="tag统计" key="tag_count">
          <ChartsCount  platform={this.state.platform}  ref="tcharts"> </ChartsCount>
        </TabPane>
      </Tabs>
      
      
 </Content>
  <Footer style={{ textAlign: 'center' }}>
      Intimate ©2020 Created by eson
  </Footer>
  </Layout>
  </Layout>
);
  }
}

// ReactDOM.render(<App />, mountNode);



export default App;